# AAT Wrest: The Archive Database Access Utility

AAT Wrest is a utility that provides access to the AAT database in order to retrieve additional metadata
which is required for certain Workspaces workflows. Such data usually includes fields such as project codes,
authors, and observation dates.

Wrest is defined as follows: to pull, force, or move by violent wringing or twisting movements.

It was decided that using 'retrieve' was too repetitive and mundane for the awesomeness of Workspaces.
Therefore, we wrest information, not retrieve information. It's more fun that way.

## How to use AAT Wrest

```
usage: aat_wrest [-h] [-sc STDCALS] [-si STDIMG] [-r RESTORE [RESTORE ...]] [-obs OBSERVATION] [-aux AUXILIARY_INGESTION] [--carta CARTA]

Archive Database Access Utility

optional arguments:
  -h, --help            show this help message and exit
  -sc STDCALS, --stdcals STDCALS
                        Find workflow metadata for standard calibrations with provided product locator
  -si STDIMG, --stdimg STDIMG
                        Find workflow metadata for standard CMS imaging with provided SDM id
  -r RESTORE [RESTORE ...], --restore RESTORE [RESTORE ...]
                        Find workflow metadata for Restores with provided EB product locator and Cal product locator
  -obs OBSERVATION, --observation OBSERVATION
                        Find display metadata for observations by SDM id
  -aux AUXILIARY_INGESTION, --auxiliary-ingestion AUXILIARY_INGESTION
                        Find auxiliary imaging metadata for ingestion
  --carta CARTA         Find image names for single image carta requests

```

AAT Wrest requires either one-or-more SDM IDs or a Science Product Locators and returns the additional
metadata required for workspaces to proceed with either workflow template rendering or other functions,
such as observation ingestion response.

There are two classes of wresters, Metadata Wresters and Observation Wresters.

### Metadata Wresters
Metadata Wresters provide information required to complete template rendering for a Workspaces workflow.
This is the most common type of information wresting in Workspaces.

Frequently, a workflow will have some templates, such as PPR.xml, that require project level data which
is not known to the Workspaces system. Therefore, such data must be retrieved prior to template rendering.

Data is wrested using one-or-more science product locators - or in the case of CMS Imaging, an SDM ID.

Available Metadata Wresters include:

|   Wrester	|   Inputs	| Description |
|---	|---	|--- |
|   *wrest_standard_cal_info*	|  SPL 	| Returns metadata required by std_calibration workflow|
|   *wrest_standard_image_info*	|  SDM ID	| Returns metadata required by std_cms_imaging workflow|
|   *wrest_restore_info*	|   SPL & Calibration SPL	| Returns the metadata required by cms_restore workflow|
|   *wrest_aux_imaging_info*	|  SPL or SDM ID  | Returns the metadata required to run image ingestion |
|   *wrest_image_name*|  SPL  | Returns the image filename for launching single image CARTA workflows|



### Observation Wresters
Observation Wresters provide information required for functionality other than workflow template rendering.

Currently, there is only one observation wrester, *wrest_observation_info*, which takes in an SDM ID
and queries the AAT database for observation data related to an ingestion-complete event.
