#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""
Tests for aat_wrest.observation_wrester
"""

import argparse

# pylint: disable=E0401, E0402
from unittest.mock import MagicMock, patch

from aat_wrest.observation_wrester import WrestObservationMetadata


args = argparse.Namespace(observation="17B-197.sb34663512.eb34806505.58108.78427738426")

result_obs = (
    '{"spl": "uid://evla/execblock/8fbfb54b-d141-42fe-b079-609339a69cba", '
    '"bands": "Ka", '
    '"array_config": "D", '
    '"obs_start_time": "1234567", '
    '"obs_end_time": "123598898", '
    '"is_srdp": "True" }'
)


def mock_wrester(args: argparse.Namespace) -> WrestObservationMetadata:
    """
    Pretend to get the information from the MDDB.

    :param args:
    :return:
    """
    with patch("psycopg2.connect") as conn:
        return WrestObservationMetadata(conn, args.observation)


wrester = mock_wrester(args)


class TestWrestObservationInfo:
    @patch("json.dumps", MagicMock(return_value=result_obs))
    def test_wrest_observation_info(self):
        wrester.conn.cursor.return_value.fetchall.return_value = [
            "uid://evla/execblock/8fbfb54b-d141-42fe-b079-609339a69cba",
            "Ka",
            "D",
            "1234567",
            "123598898",
            "True",
        ]

        assert args.observation == "17B-197.sb34663512.eb34806505.58108.78427738426"
        metadata = wrester.wrest_observation_info()

        assert (
            metadata == '{"spl": "uid://evla/execblock/8fbfb54b-d141-42fe-b079-609339a69cba", '
            '"bands": "Ka", '
            '"array_config": "D", '
            '"obs_start_time": "1234567", '
            '"obs_end_time": "123598898", '
            '"is_srdp": "True" }'
        )
